@@ -1,4 +1,4 @@
-__version__ = '1.1.0'
+__version__ = '1.1.1'
 
 import calendar
 import datetime
@@ -10,6 +10,7 @@ from typing import Union, Optional
 
 import requests
 from requests.cookies import cookiejar_from_dict
+from requests.models import Response
 
 
 def add_months(date: datetime.date, months: int) -> datetime.date:
@@ -21,6 +22,13 @@ def add_months(date: datetime.date, months: int) -> datetime.date:
     return datetime.datetime(year, month, day).date()
 
 
+def response_data(response: Response):
+    try:
+        return response.json()
+    except json.decoder.JSONDecodeError:
+        return {'text': response.text}
+
+
 @dataclass
 class Response:
     status_code: Optional[int] = 200
@@ -59,6 +67,50 @@ class PythonAnywhereApi:
         }
         self.session.timeout = timeout
 
+    def create_console(self, executable: str = 'bash', arguments: str = None,
+                       working_directory: str = None) -> Response:
+        url = self.create_url('/consoles/')
+
+        data = {'executable': executable}
+
+        if arguments:
+            data['arguments'] = arguments
+
+        if working_directory:
+            data['working_directory'] = working_directory
+
+        try:
+            response = self.session.post(url, data=data)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=response.status_code != 201,
+            data=response_data(response)
+        )
+
+    def delete_console(self, console_id: int) -> Response:
+        url = self.create_url(f'/consoles/{console_id}/')
+
+        try:
+            response = self.session.delete(url)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=response.status_code != 204,
+        )
+
     def list_consoles(self) -> Response:
         url = self.create_url('/consoles/')
 
@@ -74,11 +126,11 @@ class PythonAnywhereApi:
         return Response(
             status_code=response.status_code,
             error=response.status_code != 200,
-            data=json.loads(response.text)
+            data=response_data(response)
         )
 
     def console_latest_output(self, console_id: int) -> Response:
-        url = self.create_url(f'/consoles/{console_id}/get_latest_output')
+        url = self.create_url(f'/consoles/{console_id}/get_latest_output/')
 
         try:
             response = self.session.get(url)
@@ -92,7 +144,7 @@ class PythonAnywhereApi:
         return Response(
             status_code=response.status_code,
             error=response.status_code != 200,
-            data=json.loads(response.text)
+            data=response_data(response)
         )
 
     def console_input(self, console_id: int, input_string: str) -> Response:
@@ -112,7 +164,7 @@ class PythonAnywhereApi:
         return Response(
             status_code=response.status_code,
             error=response.status_code != 200,
-            data=json.loads(response.text)
+            data=response_data(response)
         )
 
     def get_file(self, path: str) -> Response:
@@ -133,6 +185,129 @@ class PythonAnywhereApi:
             data={'content': response.text}
         )
 
+    def create_file(self, path: str, content: bytes) -> Response:
+        url = self.create_url(f'/files/path{path}')
+
+        files = {'content': content}
+
+        try:
+            response = self.session.post(url, files=files)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=response.status_code not in (200, 201),
+        )
+
+    def delete_file(self, path) -> Response:
+        url = self.create_url(f'/files/path{path}')
+
+        try:
+            response = self.session.delete(url)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=response.status_code != 204,
+        )
+
+    def can_create_tasks(self) -> Response:
+        url = self.create_url('/user_perms/schedule/')
+
+        try:
+            response = self.session.get(url)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=False,
+            data=response_data(response)
+        )
+
+    def delete_task(self, task_id: int) -> Response:
+        url = self.create_url(f'/schedule/{task_id}/')
+
+        try:
+            response = self.session.delete(url)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=response.status_code != 204,
+        )
+
+    def create_task(self, command: str, description: str, hour: int, minute: int, enabled: bool = True,
+                    interval: str = 'daily') -> Response:
+        url = self.create_url('/schedule/')
+
+        data = {
+            'command': command,
+            'description': description,
+            'hour': hour,
+            'minute': minute,
+            'enabled': enabled,
+            'interval': interval
+        }
+
+        try:
+            response = self.session.post(url, data=data)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        if response.status_code != 201:
+            return Response(
+                status_code=response.status_code,
+                error=True
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=False,
+            data=response_data(response)
+        )
+
+    def get_tasks(self) -> Response:
+        url = self.create_url('/schedule/')
+
+        try:
+            response = self.session.get(url)
+        except requests.exceptions.RequestException:
+            return Response(
+                status_code=None,
+                error=True,
+                data={'message': traceback.format_exc()}
+            )
+
+        return Response(
+            status_code=response.status_code,
+            error=False,
+            data=response_data(response)
+        )
+
 
 class PythonAnywhereWeb:
     BASE_URL = 'https://www.pythonanywhere.com'
@@ -419,116 +594,3 @@ class PythonAnywhereWeb:
             status_code=response.status_code,
             error=False
         )
-
-    def get_tasks(self) -> Response:
-        url = self.create_url(f'/api/v0/user/{self.username}/schedule/')
-        headers = {'Referer': self.create_url(f'/user/{self.username}/tasks_tab/')}
-
-        try:
-            response = self.session.get(url, headers=headers)
-        except requests.exceptions.RequestException:
-            return Response(
-                status_code=None,
-                error=True,
-                data={'message': traceback.format_exc()}
-            )
-
-        try:
-            return Response(
-                status_code=response.status_code,
-                error=False,
-                data=json.loads(response.text)
-            )
-        except (KeyError, ValueError):
-            return Response(
-                status_code=response.status_code,
-                error=True,
-            )
-
-    def create_task(self, command: str, description: str, hour: int, minute: int, enabled: bool = True,
-                    interval: str = 'daily') -> Response:
-        url = self.create_url(f'/api/v0/user/{self.username}/schedule/')
-
-        data = {
-            'command': command,
-            'description': description,
-            'hour': hour,
-            'minute': minute,
-            'enabled': enabled,
-            'interval': interval
-        }
-
-        headers = {
-            'Referer': self.create_url(f'/user/{self.username}/tasks_tab/'),
-            'X-CSRFToken': self.get_csrf_token().data['csrf_token']
-        }
-
-        try:
-            response = self.session.post(url, data=data, headers=headers)
-        except requests.exceptions.RequestException:
-            return Response(
-                status_code=None,
-                error=True,
-                data={'message': traceback.format_exc()}
-            )
-
-        if response.status_code != 201:
-            return Response(
-                status_code=response.status_code,
-                error=True
-            )
-
-        return Response(
-            status_code=response.status_code,
-            error=False,
-            data=json.loads(response.text)
-        )
-
-    def update_task(self, task_id: int):
-        pass
-
-    def delete_task(self, task_id: int) -> Response:
-        url = self.create_url(f'/api/v0/user/{self.username}/schedule/{task_id}/')
-
-        headers = {
-            'Referer': self.create_url(f'/user/{self.username}/tasks_tab/'),
-            'X-CSRFToken': self.get_csrf_token().data['csrf_token']
-        }
-
-        try:
-            response = self.session.delete(url, headers=headers)
-        except requests.exceptions.RequestException:
-            return Response(
-                status_code=None,
-                error=True,
-                data={'message': traceback.format_exc()}
-            )
-
-        return Response(
-            status_code=response.status_code,
-            error=response.status_code != 204,
-        )
-
-    def can_create_tasks(self) -> Response:
-        url = self.create_url(f'/api/v0/user/{self.username}/user_perms/schedule/')
-        headers = {'Referer': self.create_url(f'/user/{self.username}/tasks_tab/')}
-        try:
-            response = self.session.get(url, headers=headers)
-        except requests.exceptions.RequestException:
-            return Response(
-                status_code=None,
-                error=True,
-                data={'message': traceback.format_exc()}
-            )
-
-        if response.status_code != 200:
-            return Response(
-                status_code=response.status_code,
-                error=True
-            )
-
-        return Response(
-            status_code=response.status_code,
-            error=False,
-            data=json.loads(response.text)
-        )
